--[[ Text substitutions ]]
local L = MacroTalk_Locals

local subsBase = {
	["%%[Nn]"] = function() return UnitName("player") end,
	["%%[Zz]"] = GetRealZoneText,
	["%%[Ss][Zz]"] = GetSubZoneText,
}

local sexes = {
	L["<no %s>"]:format(L["gender"]),
	MALE:lower(),
	FEMALE:lower()
}

local unitInfoUnits = {
	[""] = "player",
	["[Tt]"] = "target",
	["[Ff]"] = "focus",
	["[Mm]"] = "mouseover",
	["[Pp]"] = "pet",
}

local unitInfoPrefixes = {
	[""] = UnitName,
	
	["[Ll]"] = function(unit)
		local level = UnitLevel(unit)
		return level > 0 and level or level < 0 and "??"
	end,
	
	["[Cc]"] = UnitClass,
	
	["[Gg]"] = function(unit)
		return sexes[UnitSex(unit)]
	end,
	
	["[Rr]"] = function(unit)
		local race = UnitRace(unit)
		return race or L["<no %s>"]:format(RACE:lower())
	end,
}

for initial, unit in pairs(unitInfoUnits) do
	local noUnit = L["<no %s>"]:format(unit)
	for prefix, func in pairs(unitInfoPrefixes) do
		if initial ~= "" or prefix ~= "" then
			local code = "%%"..initial..prefix
			assert(not subsBase[code],
				L["MacroTalk: Conflicting substitutions"])
			subsBase[code] = function()
				return UnitExists(unit) and func(unit) or noUnit
			end
		end
	end
end

local substitutions = {}
local i = 1
for k, v in pairs(subsBase) do
	substitutions[i] = { code = k, func = v }
	i = i + 1
end

sort(substitutions, function(subs1, subs2)
	return subs2.code:len() < subs1.code:len()
end)

local OrigSendChatMessage = SendChatMessage
function SendChatMessage(text, ...)
	for _, substitution in ipairs(substitutions) do
		text = text:gsub(substitution.code, substitution.func())
	end
	return OrigSendChatMessage(text, ...)
end
